use std::fs::File;
use std::io::{BufRead, BufReader};

fn print_final_frequency(ints: &Vec<i32>) -> i32 {
    ints.iter().sum::<i32>()
}

fn print_first_duped_frequency(line_count: usize, offsets: &Vec<i32>) -> i32 {
    let mut freaks: Vec<i32> = vec![0];
    duped_frequency(0, line_count, offsets, &mut freaks)
}

fn duped_frequency(
    index: usize,
    max_count: usize,
    offsets: &Vec<i32>,
    freaks: &mut Vec<i32>,
) -> i32 {
    let cur_offset = offsets.get(index).unwrap();
    let next_freq = freaks.last().unwrap() + cur_offset;
    let mut found = false;
    for freq in freaks.iter() {
        if freq == &next_freq {
            found = true;
            break;
        }
    }
    if found {
        next_freq
    } else {
        let next_index = (index + 1) % max_count;
        freaks.push(next_freq);
        duped_frequency(next_index, max_count, offsets, freaks)
    }
}

fn main() {
    let ints: Vec<i32> = BufReader::new(File::open("input").unwrap())
        .lines()
        .map(|line| line.unwrap().parse::<i32>().unwrap())
        .collect();
    let line_count: usize = ints.len();
    let frequency = print_final_frequency(&ints);
    println!("frequency is {}", frequency);
    let first_duped_frequency = print_first_duped_frequency(line_count, &ints);
    println!("first duped frequency is {}", first_duped_frequency);
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn test_part_one() {
        let ex1 = vec![1, 1, 1];
        let ex2 = vec![1, 1, -2];
        let ex3 = vec![-1, -2, -3];
        assert_eq!(print_final_frequency(&ex1), 3);
        assert_eq!(print_final_frequency(&ex2), 0);
        assert_eq!(print_final_frequency(&ex3), -6);
    }

    #[test]
    fn test_part_two() {
        let ex1 = vec![1, -1];
        let ex2 = vec![3, 3, 4, -2, -4];
        let ex3 = vec![-6, 3, 8, 5, -6];
        let ex4 = vec![7, 7, -2, -7, -4];
        assert_eq!(print_first_duped_frequency(ex1.len(), &ex1), 0);
        assert_eq!(print_first_duped_frequency(ex2.len(), &ex2), 10);
        assert_eq!(print_first_duped_frequency(ex3.len(), &ex3), 5);
        assert_eq!(print_first_duped_frequency(ex4.len(), &ex4), 14);
    }
}
