extern crate edit_distance;

use edit_distance::edit_distance;
use std::collections::HashMap;
use std::fs::File;
use std::io::{BufRead, BufReader};

fn get_char_counts(input: &String) -> (bool, bool) {
    let mut has_two = false;
    let mut has_three = false;
    let mut map = HashMap::new();
    for char in input.chars() {
        map.entry(char).and_modify(|x| *x += 1).or_insert(1);
    }
    for (_char, count) in map {
        if has_two && has_three {
            break;
        }
        if count == 2 {
            has_two = true;
        } else if count == 3 {
            has_three = true;
        }
    }
    (has_two, has_three)
}

fn calc_checksum(lines: &Vec<String>) -> i32 {
    let mut two_count = 0;
    let mut three_count = 0;
    for line in lines.iter() {
        let (has_two, has_three) = get_char_counts(line);
        if has_two {
            two_count += 1;
        }
        if has_three {
            three_count += 1;
        }
    }
    two_count * three_count
}

fn find_single_char_difference(lines: &mut Vec<String>) -> String {
    let line = lines
        .pop()
        .expect("ran out of lines to find the single char difference!");
    for other in lines.iter() {
        if edit_distance(&line, other) == 1 {
            let mut result = String::new();
            let mut other_iter = other.chars();
            for c in line.chars() {
                if c == other_iter.nth(0).unwrap() {
                    result.push(c);
                }
            }
            println!("{} and {}", line, other);
            return result;
        }
    }
    find_single_char_difference(lines)
}

fn main() {
    let mut lines: Vec<String> = BufReader::new(File::open("input").unwrap())
        .lines()
        .map(|line| line.unwrap())
        .collect();
    let checksum = calc_checksum(&lines);
    println!("checksum: {}", checksum);
    let common_chars = find_single_char_difference(&mut lines);
    println!("common chars: {}", common_chars);
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn test_part_one() {
        let ex1 = vec![
            String::from("abcdef"),
            String::from("bababc"),
            String::from("abbcde"),
            String::from("abcccd"),
            String::from("aabcdd"),
            String::from("abcdee"),
            String::from("ababab"),
        ];
        assert_eq!(calc_checksum(&ex1), 12);
    }

    #[test]
    fn test_part_two() {
        let mut ex1 = vec![
            String::from("abcde"),
            String::from("fghij"),
            String::from("klmno"),
            String::from("pqrst"),
            String::from("fguij"),
            String::from("axcye"),
            String::from("wvxyz"),
        ];
        assert_eq!(find_single_char_difference(&mut ex1), String::from("fgij"));
    }
}
