use anyhow::Result;
use std::fs;

pub fn run() -> Result<()> {
    #[cfg(not(feature = "test_input"))]
    let file_contents = fs::read_to_string("day1.txt")?;

    #[cfg(feature = "test_input")]
    let file_contents = fs::read_to_string("tests/day1.txt")?;

    let lines = file_contents.lines();
    let mut calories = Vec::with_capacity(lines.clone().count());
    let mut count: u32 = 0;

    for line in lines {
        if line.is_empty() {
            calories.push(count);
            count = 0;
        } else {
            count += line.parse::<u32>().expect("not a number");
        }
    }

    let max = calories.iter().max().expect("Should have been a number");
    println!("Maximum calories is {}", max);

    let mut sorted_calories = calories.clone();
    sorted_calories.sort_by(|a, b| b.cmp(a));
    let top_three: u32 = sorted_calories
        .get(0..3)
        .expect("Not able to be sorted")
        .iter()
        .sum();
    println!("Top 3 calories {}", top_three);
    Ok(())
}
