use anyhow::Result;
use std::collections::HashSet;
use std::fs;

fn get_priority(t: &char) -> u32 {
    if t.is_ascii_uppercase() {
        *t as u32 - 65 + 27
    } else if t.is_ascii_lowercase() {
        *t as u32 - 96
    } else {
        0
    }
}

pub fn run() -> Result<()> {
    #[cfg(not(feature = "test_input"))]
    let file_contents = fs::read_to_string("day3.txt")?;

    #[cfg(feature = "test_input")]
    let file_contents = fs::read_to_string("tests/day3.txt")?;

    let lines = file_contents.lines();
    let mut rucksacks: Vec<u32> = Vec::with_capacity(1000);
    let mut rucksacks2: Vec<u32> = Vec::with_capacity(1000);

    for line in lines {
        let len = line.len();
        let mid = len / 2;
        let left = line[0..mid].chars();
        let right = line[mid..len].chars();
        let leftmap: HashSet<char> = HashSet::from_iter(left);
        let rightmap: HashSet<char> = HashSet::from_iter(right);
        for dupe in leftmap.intersection(&rightmap) {
            rucksacks.push(get_priority(dupe));
            /*if dupe.is_ascii_uppercase() {
                let val = *dupe as u32 - 65 + 27;
                rucksacks.push(val);
            } else if dupe.is_ascii_lowercase() {
                let val = *dupe as u32 - 96;
                rucksacks.push(val);
            }*/
        }
    }
    println!("part one priorities {}", rucksacks.into_iter().sum::<u32>());

    let mut elves = file_contents.lines();
    loop {
        if let Some(elf1) = elves.next() {
            let elf2 = elves.next().unwrap();
            let elf3 = elves.next().unwrap();
            let elf1map: HashSet<char> = HashSet::from_iter(elf1.chars());
            let elf2map: HashSet<char> = HashSet::from_iter(elf2.chars());
            let elf3map: HashSet<char> = HashSet::from_iter(elf3.chars());

            for dupe in elf1map
                .iter()
                .filter(|t| elf2map.contains(t) && elf3map.contains(t))
            {
                rucksacks2.push(get_priority(dupe));
            }
        } else {
            break;
        }
    }
    println!(
        "part two priorities {}",
        rucksacks2.into_iter().sum::<u32>()
    );

    Ok(())
}
