use anyhow::Result;
use std::fs;

type World = [[u8; 100]; 100];
type Visible = [[bool; 100]; 100];

pub fn run() -> Result<()> {
    #[cfg(not(feature = "test_input"))]
    let file_contents = fs::read_to_string("day8.txt")?;

    #[cfg(feature = "test_input")]
    let file_contents = fs::read_to_string("tests/day8.txt")?;

    let mut world: World = [[0; 100]; 100];

    let mut size = 0;
    for (row, line) in file_contents.lines().enumerate() {
        size = row;
        for (col, x) in line.chars().enumerate() {
            world[row][col] = x.to_digit(10).expect("invalid digit") as u8;
        }
    }
    size += 1;
    println!("world size {}", size);
    for row in world.iter().take(size) {
        for col in row.iter().take(size) {
            print!("{}", *col);
        }
        println!();
    }

    let mut visible: Visible = [[false; 100]; 100];
    println!(
        "part one {}",
        part_one_visibility(&world, size, &mut visible)
    );
    println!("part two {}", part_two_score(&world, size, &visible));

    Ok(())
}

fn part_one_visibility(world: &World, max_size: usize, visible: &mut Visible) -> usize {
    for i in 0..max_size {
        visible[i][max_size - 1] = true;
        visible[i][0] = true;
        visible[0][i] = true;
        visible[max_size - 1][i] = true;
    }

    biggest_top(world, max_size, visible);
    biggest_bottom(world, max_size, visible);
    biggest_left(world, max_size, visible);
    biggest_right(world, max_size, visible);

    println!("visible trees");
    let mut count: usize = 0;
    for row in visible.iter().take(max_size) {
        for col in row.iter().take(max_size) {
            if *col {
                count += 1;
                print!("1");
            } else {
                print!("0");
            }
        }
        println!();
    }

    count
}

fn part_two_score(world: &World, max_size: usize, visible: &Visible) -> usize {
    let mut score: usize = 0;

    for row in 1..(max_size - 1) {
        for col in 1..(max_size - 1) {
            if visible[row][col] {
                let new_score = get_visibility_score(world, max_size, row, col);
                if new_score > score {
                    score = new_score;
                }
            }
        }
    }

    score
}

fn get_visibility_score(world: &World, max_size: usize, row: usize, col: usize) -> usize {
    let height = world[row][col];

    let mut north: usize = 0;
    for k in (0..row).rev() {
        if world[k][col] < height {
            north += 1;
        } else if world[k][col] >= height {
            north += 1;
            break;
        } else {
            break;
        }
    }

    let mut south: usize = 0;
    for i in (row + 1)..max_size {
        if world[i][col] < height {
            south += 1;
        } else if world[i][col] >= height {
            south += 1;
            break;
        } else {
            break;
        }
    }

    let mut west: usize = 0;
    for k in (0..col).rev() {
        if world[row][k] < height {
            west += 1;
        } else if world[row][k] >= height {
            west += 1;
            break;
        } else {
            break;
        }
    }

    let mut east: usize = 0;
    for i in (col + 1)..max_size {
        if world[row][i] < height {
            east += 1;
        } else if world[row][i] >= height {
            east += 1;
            break;
        } else {
            break;
        }
    }

    north * south * east * west
}

fn biggest_left(world: &World, max_size: usize, visible: &mut Visible) {
    let mut sizes: [u8; 100] = [0; 100];

    for i in 0..max_size {
        sizes[i] = world[i][0];
    }

    for row in 1..max_size {
        for col in 1..max_size {
            if world[row][col] > sizes[row] {
                visible[row][col] = true;
                sizes[row] = world[row][col];
            }
        }
    }
}

fn biggest_right(world: &World, max_size: usize, visible: &mut Visible) {
    let mut sizes: [u8; 100] = [0; 100];

    for i in 0..max_size {
        sizes[i] = world[i][max_size];
    }

    for row in 1..max_size {
        for j in 1..max_size {
            let col = max_size - j;
            if world[row][col] > sizes[row] {
                visible[row][col] = true;
                sizes[row] = world[row][col];
            }
        }
    }
}

fn biggest_top(world: &World, max_size: usize, visible: &mut Visible) {
    let mut sizes: [u8; 100] = [0; 100];

    sizes[..max_size].copy_from_slice(&world[0][..max_size]);

    for col in 1..max_size {
        for row in 1..max_size {
            if world[row][col] > sizes[col] {
                visible[row][col] = true;
                sizes[col] = world[row][col];
            }
        }
    }
}

fn biggest_bottom(world: &World, max_size: usize, visible: &mut Visible) {
    let mut sizes: [u8; 100] = [0; 100];

    for i in 0..max_size {
        sizes[i] = world[max_size - 1][i];
    }

    for col in 1..max_size {
        for i in 1..max_size {
            let row = max_size - i;
            if world[row][col] > sizes[col] {
                visible[row][col] = true;
                sizes[col] = world[row][col];
            }
        }
    }
}
